@@ -6,16 +6,16 @@
 use strict;
 use warnings;
 
-use Business::AU::Ledger::Create;
+use Business::AU::Ledger::Util::Create;
 
 # --------------------------------
 
-my($creator) = Business::AU::Ledger::Create -> new(verbose => 1);
+my($creator) = Business::AU::Ledger::Util::Create -> new(verbose => 1);
 
 print "Creating tables for database 'ledger'. \n";
 
-$creator -> drop_all_tables();
-$creator -> create_all_tables();
+$creator -> drop_all_tables;
+$creator -> create_all_tables;
 
 print "Finished creating tables. \n";
 print "------------------------- \n";
