@@ -6,15 +6,15 @@
 use strict;
 use warnings;
 
-use Business::AU::Ledger::Create;
+use Business::AU::Ledger::Util::Create;
 
 # ----------------------------
 
-my($creator) = Business::AU::Ledger::Create -> new(verbose => 1);
+my($creator) = Business::AU::Ledger::Util::Create -> new(verbose => 1);
 
 print "Populating tables for database 'ledger'. \n";
 
-$creator -> populate_all_tables();
+$creator -> populate_all_tables;
 
 print "Finished populating tables \n";
 print "-------------------------- \n";
